/*
 * Copyright (C) 2018 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.android.settings.homepage;

import static com.google.common.truth.Truth.assertThat;

import static org.mockito.Mockito.spy;
import static org.mockito.Mockito.when;

import android.content.Context;
import android.util.FeatureFlagUtils;

import com.android.settings.R;
import com.android.settings.core.FeatureFlags;

import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.robolectric.RobolectricTestRunner;
import org.robolectric.RuntimeEnvironment;

@RunWith(RobolectricTestRunner.class)
public class TopLevelSettingsTest {
    private Context mContext;
    private TopLevelSettings mSettings;

    @Before
    public void setUp() {
        mContext = RuntimeEnvironment.application;
        mSettings = spy(new TopLevelSettings());
        when(mSettings.getContext()).thenReturn(mContext);
    }

    @Test
    public void shouldForceRoundedIcon_true() {
        assertThat(mSettings.shouldForceRoundedIcon()).isTrue();
    }

    @Test
    public void getPreferenceScreenResId_silkyHomeDisabled_defaultSettings() {
        FeatureFlagUtils.setEnabled(mContext, FeatureFlags.SILKY_HOME, false);
        assertThat(mSettings.getPreferenceScreenResId()).isEqualTo(R.xml.top_level_settings);
    }

    @Test
    public void getPreferenceScreenResId_silkyHomeEnabled_groupedSettings() {
        FeatureFlagUtils.setEnabled(mContext, FeatureFlags.SILKY_HOME, true);
        assertThat(mSettings.getPreferenceScreenResId()).isEqualTo(
                R.xml.top_level_settings_grouped);
    }
}
